OiRA - Online διαδραστική Αξιολόγηση Κινδύνων

# Perfumes

Perfumes in cosmetic products may cause allergies. Pure odour allergies are not particularly common, but many people with problems in the respiratory tract and asthma suffer intense reactions to the odour from strong perfume.

1. Προετοιμασία
2. Αναγνώριση
   1. 1 The building
   2. 2 Working Environment
   3. 3 Preventing work related injuries
   4. 4 Creating a good work atmosphere and reducing stress
   5. 5 Chemical Health Risks
      1. 5.1 Handling chemical hairdressing products
      2. 5.2 Shampoo and water
      3. 5.3 Hair dyes
      4. 5.4 Perfumes
      5. 5.5 Hazardous substances in products - Selection of products
      6. 5.6 Gloves
      7. 5.7 Air quality and ventilation
   6. 6 Accidents
   7. 7 Occupational diseases
3. Αξιολόγηση
4. Σχέδιο Δράσης
5. Αναφορά

Δημιουργήθηκε από EU-OSHA. | Σχετικά | Ιδιωτικότητα | Αποποίηση ευθυνών | Άδεια GPL |